@@ -1,6 +1,7 @@
 """
 Main CLI entrypoint.
 """
+
 import sys
 
 
@@ -9,8 +10,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.DynamoDB 1.26.97\nVersion:         1.26.97.post1\nBuilder"
-        " version: 7.14.1\nDocs:           "
+        "Type annotations for boto3.DynamoDB 1.34.21\nVersion:         1.34.21\nBuilder version:"
+        " 7.23.1\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb//\nBoto3 docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.26.97.post1")
+    print("1.34.21")
 
 
 def main() -> None:
