@@ -13,11 +13,9 @@ Usage::
     client: DynamoDBClient = session.client("dynamodb")
     ```
 """
+
 import sys
-from collections.abc import Mapping, Sequence
-from datetime import datetime
-from decimal import Decimal
-from typing import Any, Dict, Set, Type, Union, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -27,10 +25,12 @@ from .literals import (
     ConditionalOperatorType,
     ContributorInsightsActionType,
     ExportFormatType,
+    ExportTypeType,
     InputCompressionTypeType,
     InputFormatType,
     ReturnConsumedCapacityType,
     ReturnItemCollectionMetricsType,
+    ReturnValuesOnConditionCheckFailureType,
     ReturnValueType,
     S3SseAlgorithmType,
     SelectType,
@@ -45,7 +45,6 @@ from .paginator import (
 )
 from .type_defs import (
     AttributeDefinitionTypeDef,
-    AttributeValueTypeDef,
     AttributeValueUpdateTypeDef,
     AutoScalingSettingsUpdateTypeDef,
     BatchExecuteStatementOutputTypeDef,
@@ -83,6 +82,7 @@ from .type_defs import (
     GlobalSecondaryIndexUpdateTypeDef,
     GlobalTableGlobalSecondaryIndexSettingsUpdateTypeDef,
     ImportTableOutputTypeDef,
+    IncrementalExportSpecificationTypeDef,
     InputFormatOptionsTypeDef,
     KeysAndAttributesTypeDef,
     KeySchemaElementTypeDef,
@@ -113,11 +113,13 @@ from .type_defs import (
     StreamSpecificationTypeDef,
     TableCreationParametersTypeDef,
     TagTypeDef,
+    TimestampTypeDef,
     TimeToLiveSpecificationTypeDef,
     TransactGetItemsOutputTypeDef,
     TransactGetItemTypeDef,
     TransactWriteItemsOutputTypeDef,
     TransactWriteItemTypeDef,
+    UniversalAttributeValueTypeDef,
     UpdateContinuousBackupsOutputTypeDef,
     UpdateContributorInsightsOutputTypeDef,
     UpdateGlobalTableOutputTypeDef,
@@ -130,16 +132,15 @@ from .type_defs import (
 )
 from .waiter import TableExistsWaiter, TableNotExistsWaiter
 
-if sys.version_info >= (3, 9):
+if sys.version_info >= (3, 12):
     from typing import Literal
 else:
     from typing_extensions import Literal
 
-
 __all__ = ("DynamoDBClient",)
 
 
-class BotocoreClientError(BaseException):
+class BotocoreClientError(Exception):
     MSG_TEMPLATE: str
 
     def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
@@ -203,11 +204,12 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         Statements: Sequence[BatchStatementRequestTypeDef],
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
     ) -> BatchExecuteStatementOutputTypeDef:
         """
         This operation allows you to perform batch reads or writes on data stored in
-        DynamoDB, using PartiQL.
+        DynamoDB, using
+        PartiQL.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.batch_execute_statement)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#batch_execute_statement)
@@ -217,11 +219,12 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         RequestItems: Mapping[str, KeysAndAttributesTypeDef],
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
     ) -> BatchGetItemOutputTypeDef:
         """
         The `BatchGetItem` operation returns the attributes of one or more items from
-        one or more tables.
+        one or more
+        tables.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.batch_get_item)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#batch_get_item)
@@ -232,7 +235,7 @@ class DynamoDBClient(BaseClient):
         *,
         RequestItems: Mapping[str, Sequence[WriteRequestTypeDef]],
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
-        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
     ) -> BatchWriteItemOutputTypeDef:
         """
         The `BatchWriteItem` operation puts or deletes multiple items in one or more
@@ -290,7 +293,7 @@ class DynamoDBClient(BaseClient):
         SSESpecification: SSESpecificationTypeDef = ...,
         Tags: Sequence[TagTypeDef] = ...,
         TableClass: TableClassType = ...,
-        DeletionProtectionEnabled: bool = ...
+        DeletionProtectionEnabled: bool = ...,
     ) -> CreateTableOutputTypeDef:
         """
         The `CreateTable` operation adds a new table to your account.
@@ -311,28 +314,7 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        Key: Mapping[
-            str,
-            Union[
-                AttributeValueTypeDef,
-                Union[
-                    bytes,
-                    bytearray,
-                    str,
-                    int,
-                    Decimal,
-                    bool,
-                    Set[int],
-                    Set[Decimal],
-                    Set[str],
-                    Set[bytes],
-                    Set[bytearray],
-                    Sequence[Any],
-                    Mapping[str, Any],
-                    None,
-                ],
-            ],
-        ],
+        Key: Mapping[str, UniversalAttributeValueTypeDef],
         Expected: Mapping[str, ExpectedAttributeValueTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ReturnValues: ReturnValueType = ...,
@@ -340,28 +322,8 @@ class DynamoDBClient(BaseClient):
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
         ConditionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                AttributeValueTypeDef,
-                Union[
-                    bytes,
-                    bytearray,
-                    str,
-                    int,
-                    Decimal,
-                    bool,
-                    Set[int],
-                    Set[Decimal],
-                    Set[str],
-                    Set[bytes],
-                    Set[bytearray],
-                    Sequence[Any],
-                    Mapping[str, Any],
-                    None,
-                ],
-            ],
-        ] = ...
+        ExpressionAttributeValues: Mapping[str, UniversalAttributeValueTypeDef] = ...,
+        ReturnValuesOnConditionCheckFailure: ReturnValuesOnConditionCheckFailureType = ...,
     ) -> DeleteItemOutputTypeDef:
         """
         Deletes a single item in a table by primary key.
@@ -391,7 +353,8 @@ class DynamoDBClient(BaseClient):
     ) -> DescribeContinuousBackupsOutputTypeDef:
         """
         Checks the status of continuous backups and point in time recovery on the
-        specified table.
+        specified
+        table.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.describe_continuous_backups)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#describe_continuous_backups)
@@ -402,7 +365,8 @@ class DynamoDBClient(BaseClient):
     ) -> DescribeContributorInsightsOutputTypeDef:
         """
         Returns information about contributor insights for a given table or global
-        secondary index.
+        secondary
+        index.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.describe_contributor_insights)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#describe_contributor_insights)
@@ -464,7 +428,8 @@ class DynamoDBClient(BaseClient):
         """
         Returns the current provisioned-capacity quotas for your Amazon Web Services
         account in a Region, both for the Region as a whole and for any one DynamoDB
-        table that you create there.
+        table that you create
+        there.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.describe_limits)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#describe_limits)
@@ -473,7 +438,8 @@ class DynamoDBClient(BaseClient):
     def describe_table(self, *, TableName: str) -> DescribeTableOutputTypeDef:
         """
         Returns information about the table, including the current status of the table,
-        when it was created, the primary key schema, and any indexes on the table.
+        when it was created, the primary key schema, and any indexes on the
+        table.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.describe_table)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#describe_table)
@@ -512,7 +478,8 @@ class DynamoDBClient(BaseClient):
     ) -> KinesisStreamingDestinationOutputTypeDef:
         """
         Starts table data replication to the specified Kinesis data stream at a
-        timestamp chosen during the enable workflow.
+        timestamp chosen during the enable
+        workflow.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.enable_kinesis_streaming_destination)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#enable_kinesis_streaming_destination)
@@ -522,35 +489,17 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         Statement: str,
-        Parameters: Sequence[
-            Union[
-                AttributeValueTypeDef,
-                Union[
-                    bytes,
-                    bytearray,
-                    str,
-                    int,
-                    Decimal,
-                    bool,
-                    Set[int],
-                    Set[Decimal],
-                    Set[str],
-                    Set[bytes],
-                    Set[bytearray],
-                    Sequence[Any],
-                    Mapping[str, Any],
-                    None,
-                ],
-            ]
-        ] = ...,
+        Parameters: Sequence[UniversalAttributeValueTypeDef] = ...,
         ConsistentRead: bool = ...,
         NextToken: str = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
-        Limit: int = ...
+        Limit: int = ...,
+        ReturnValuesOnConditionCheckFailure: ReturnValuesOnConditionCheckFailureType = ...,
     ) -> ExecuteStatementOutputTypeDef:
         """
         This operation allows you to perform reads and singleton writes on data stored
-        in DynamoDB, using PartiQL.
+        in DynamoDB, using
+        PartiQL.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.execute_statement)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#execute_statement)
@@ -561,11 +510,12 @@ class DynamoDBClient(BaseClient):
         *,
         TransactStatements: Sequence[ParameterizedStatementTypeDef],
         ClientRequestToken: str = ...,
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
     ) -> ExecuteTransactionOutputTypeDef:
         """
         This operation allows you to perform transactional reads or writes on data
-        stored in DynamoDB, using PartiQL.
+        stored in DynamoDB, using
+        PartiQL.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.execute_transaction)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#execute_transaction)
@@ -576,13 +526,15 @@ class DynamoDBClient(BaseClient):
         *,
         TableArn: str,
         S3Bucket: str,
-        ExportTime: Union[datetime, str] = ...,
+        ExportTime: TimestampTypeDef = ...,
         ClientToken: str = ...,
         S3BucketOwner: str = ...,
         S3Prefix: str = ...,
         S3SseAlgorithm: S3SseAlgorithmType = ...,
         S3SseKmsKeyId: str = ...,
-        ExportFormat: ExportFormatType = ...
+        ExportFormat: ExportFormatType = ...,
+        ExportType: ExportTypeType = ...,
+        IncrementalExportSpecification: IncrementalExportSpecificationTypeDef = ...,
     ) -> ExportTableToPointInTimeOutputTypeDef:
         """
         Exports table data to an S3 bucket.
@@ -609,37 +561,17 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        Key: Mapping[
-            str,
-            Union[
-                AttributeValueTypeDef,
-                Union[
-                    bytes,
-                    bytearray,
-                    str,
-                    int,
-                    Decimal,
-                    bool,
-                    Set[int],
-                    Set[Decimal],
-                    Set[str],
-                    Set[bytes],
-                    Set[bytearray],
-                    Sequence[Any],
-                    Mapping[str, Any],
-                    None,
-                ],
-            ],
-        ],
+        Key: Mapping[str, UniversalAttributeValueTypeDef],
         AttributesToGet: Sequence[str] = ...,
         ConsistentRead: bool = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ProjectionExpression: str = ...,
-        ExpressionAttributeNames: Mapping[str, str] = ...
+        ExpressionAttributeNames: Mapping[str, str] = ...,
     ) -> GetItemOutputTypeDef:
         """
         The `GetItem` operation returns a set of attributes for the item with the given
-        primary key.
+        primary
+        key.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.get_item)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#get_item)
@@ -653,7 +585,7 @@ class DynamoDBClient(BaseClient):
         TableCreationParameters: TableCreationParametersTypeDef,
         ClientToken: str = ...,
         InputFormatOptions: InputFormatOptionsTypeDef = ...,
-        InputCompressionType: InputCompressionTypeType = ...
+        InputCompressionType: InputCompressionTypeType = ...,
     ) -> ImportTableOutputTypeDef:
         """
         Imports table data from an S3 bucket.
@@ -667,13 +599,15 @@ class DynamoDBClient(BaseClient):
         *,
         TableName: str = ...,
         Limit: int = ...,
-        TimeRangeLowerBound: Union[datetime, str] = ...,
-        TimeRangeUpperBound: Union[datetime, str] = ...,
+        TimeRangeLowerBound: TimestampTypeDef = ...,
+        TimeRangeUpperBound: TimestampTypeDef = ...,
         ExclusiveStartBackupArn: str = ...,
-        BackupType: BackupTypeFilterType = ...
+        BackupType: BackupTypeFilterType = ...,
     ) -> ListBackupsOutputTypeDef:
         """
-        List backups associated with an Amazon Web Services account.
+        List DynamoDB backups that are associated with an Amazon Web Services account
+        and weren't made with Amazon Web Services
+        Backup.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.list_backups)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#list_backups)
@@ -684,7 +618,8 @@ class DynamoDBClient(BaseClient):
     ) -> ListContributorInsightsOutputTypeDef:
         """
         Returns a list of ContributorInsightsSummary for a table and all its global
-        secondary indexes.
+        secondary
+        indexes.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.list_contributor_insights)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#list_contributor_insights)
@@ -745,28 +680,7 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        Item: Mapping[
-            str,
-            Union[
-                AttributeValueTypeDef,
-                Union[
-                    bytes,
-                    bytearray,
-                    str,
-                    int,
-                    Decimal,
-                    bool,
-                    Set[int],
-                    Set[Decimal],
-                    Set[str],
-                    Set[bytes],
-                    Set[bytearray],
-                    Sequence[Any],
-                    Mapping[str, Any],
-                    None,
-                ],
-            ],
-        ],
+        Item: Mapping[str, UniversalAttributeValueTypeDef],
         Expected: Mapping[str, ExpectedAttributeValueTypeDef] = ...,
         ReturnValues: ReturnValueType = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
@@ -774,28 +688,8 @@ class DynamoDBClient(BaseClient):
         ConditionalOperator: ConditionalOperatorType = ...,
         ConditionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                AttributeValueTypeDef,
-                Union[
-                    bytes,
-                    bytearray,
-                    str,
-                    int,
-                    Decimal,
-                    bool,
-                    Set[int],
-                    Set[Decimal],
-                    Set[str],
-                    Set[bytes],
-                    Set[bytearray],
-                    Sequence[Any],
-                    Mapping[str, Any],
-                    None,
-                ],
-            ],
-        ] = ...
+        ExpressionAttributeValues: Mapping[str, UniversalAttributeValueTypeDef] = ...,
+        ReturnValuesOnConditionCheckFailure: ReturnValuesOnConditionCheckFailureType = ...,
     ) -> PutItemOutputTypeDef:
         """
         Creates a new item, or replaces an old item with a new item.
@@ -817,59 +711,18 @@ class DynamoDBClient(BaseClient):
         QueryFilter: Mapping[str, ConditionTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ScanIndexForward: bool = ...,
-        ExclusiveStartKey: Mapping[
-            str,
-            Union[
-                AttributeValueTypeDef,
-                Union[
-                    bytes,
-                    bytearray,
-                    str,
-                    int,
-                    Decimal,
-                    bool,
-                    Set[int],
-                    Set[Decimal],
-                    Set[str],
-                    Set[bytes],
-                    Set[bytearray],
-                    Sequence[Any],
-                    Mapping[str, Any],
-                    None,
-                ],
-            ],
-        ] = ...,
+        ExclusiveStartKey: Mapping[str, UniversalAttributeValueTypeDef] = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ProjectionExpression: str = ...,
         FilterExpression: str = ...,
         KeyConditionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                AttributeValueTypeDef,
-                Union[
-                    bytes,
-                    bytearray,
-                    str,
-                    int,
-                    Decimal,
-                    bool,
-                    Set[int],
-                    Set[Decimal],
-                    Set[str],
-                    Set[bytes],
-                    Set[bytearray],
-                    Sequence[Any],
-                    Mapping[str, Any],
-                    None,
-                ],
-            ],
-        ] = ...
+        ExpressionAttributeValues: Mapping[str, UniversalAttributeValueTypeDef] = ...,
     ) -> QueryOutputTypeDef:
         """
         You must provide the name of the partition key attribute and a single value for
-        that attribute.
+        that
+        attribute.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.query)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#query)
@@ -884,7 +737,7 @@ class DynamoDBClient(BaseClient):
         GlobalSecondaryIndexOverride: Sequence[GlobalSecondaryIndexTypeDef] = ...,
         LocalSecondaryIndexOverride: Sequence[LocalSecondaryIndexTypeDef] = ...,
         ProvisionedThroughputOverride: ProvisionedThroughputTypeDef = ...,
-        SSESpecificationOverride: SSESpecificationTypeDef = ...
+        SSESpecificationOverride: SSESpecificationTypeDef = ...,
     ) -> RestoreTableFromBackupOutputTypeDef:
         """
         Creates a new table from an existing backup.
@@ -900,16 +753,17 @@ class DynamoDBClient(BaseClient):
         SourceTableArn: str = ...,
         SourceTableName: str = ...,
         UseLatestRestorableTime: bool = ...,
-        RestoreDateTime: Union[datetime, str] = ...,
+        RestoreDateTime: TimestampTypeDef = ...,
         BillingModeOverride: BillingModeType = ...,
         GlobalSecondaryIndexOverride: Sequence[GlobalSecondaryIndexTypeDef] = ...,
         LocalSecondaryIndexOverride: Sequence[LocalSecondaryIndexTypeDef] = ...,
         ProvisionedThroughputOverride: ProvisionedThroughputTypeDef = ...,
-        SSESpecificationOverride: SSESpecificationTypeDef = ...
+        SSESpecificationOverride: SSESpecificationTypeDef = ...,
     ) -> RestoreTableToPointInTimeOutputTypeDef:
         """
         Restores the specified table to the specified point in time within
-        `EarliestRestorableDateTime` and `LatestRestorableDateTime`.
+        `EarliestRestorableDateTime` and
+        `LatestRestorableDateTime`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.restore_table_to_point_in_time)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#restore_table_to_point_in_time)
@@ -925,61 +779,20 @@ class DynamoDBClient(BaseClient):
         Select: SelectType = ...,
         ScanFilter: Mapping[str, ConditionTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
-        ExclusiveStartKey: Mapping[
-            str,
-            Union[
-                AttributeValueTypeDef,
-                Union[
-                    bytes,
-                    bytearray,
-                    str,
-                    int,
-                    Decimal,
-                    bool,
-                    Set[int],
-                    Set[Decimal],
-                    Set[str],
-                    Set[bytes],
-                    Set[bytearray],
-                    Sequence[Any],
-                    Mapping[str, Any],
-                    None,
-                ],
-            ],
-        ] = ...,
+        ExclusiveStartKey: Mapping[str, UniversalAttributeValueTypeDef] = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         TotalSegments: int = ...,
         Segment: int = ...,
         ProjectionExpression: str = ...,
         FilterExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                AttributeValueTypeDef,
-                Union[
-                    bytes,
-                    bytearray,
-                    str,
-                    int,
-                    Decimal,
-                    bool,
-                    Set[int],
-                    Set[Decimal],
-                    Set[str],
-                    Set[bytes],
-                    Set[bytearray],
-                    Sequence[Any],
-                    Mapping[str, Any],
-                    None,
-                ],
-            ],
-        ] = ...,
-        ConsistentRead: bool = ...
+        ExpressionAttributeValues: Mapping[str, UniversalAttributeValueTypeDef] = ...,
+        ConsistentRead: bool = ...,
     ) -> ScanOutputTypeDef:
         """
         The `Scan` operation returns one or more items and item attributes by accessing
-        every item in a table or a secondary index.
+        every item in a table or a secondary
+        index.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.scan)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#scan)
@@ -999,11 +812,12 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TransactItems: Sequence[TransactGetItemTypeDef],
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
     ) -> TransactGetItemsOutputTypeDef:
         """
-        `TransactGetItems` is a synchronous operation that atomically retrieves multiple
-        items from one or more tables (but not from indexes) in a single account and
+        `TransactGetItems` is a synchronous operation that atomically retrieves
+        multiple items from one or more tables (but not from indexes) in a single
+        account and
         Region.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.transact_get_items)
@@ -1016,11 +830,12 @@ class DynamoDBClient(BaseClient):
         TransactItems: Sequence[TransactWriteItemTypeDef],
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
-        ClientRequestToken: str = ...
+        ClientRequestToken: str = ...,
     ) -> TransactWriteItemsOutputTypeDef:
         """
         `TransactWriteItems` is a synchronous write operation that groups up to 100
-        action requests.
+        action
+        requests.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.transact_write_items)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#transact_write_items)
@@ -1040,11 +855,12 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        PointInTimeRecoverySpecification: PointInTimeRecoverySpecificationTypeDef
+        PointInTimeRecoverySpecification: PointInTimeRecoverySpecificationTypeDef,
     ) -> UpdateContinuousBackupsOutputTypeDef:
         """
         `UpdateContinuousBackups` enables or disables point in time recovery for the
-        specified table.
+        specified
+        table.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.update_continuous_backups)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#update_continuous_backups)
@@ -1055,7 +871,7 @@ class DynamoDBClient(BaseClient):
         *,
         TableName: str,
         ContributorInsightsAction: ContributorInsightsActionType,
-        IndexName: str = ...
+        IndexName: str = ...,
     ) -> UpdateContributorInsightsOutputTypeDef:
         """
         Updates the status for contributor insights for a specific table or index.
@@ -1084,7 +900,7 @@ class DynamoDBClient(BaseClient):
         GlobalTableGlobalSecondaryIndexSettingsUpdate: Sequence[
             GlobalTableGlobalSecondaryIndexSettingsUpdateTypeDef
         ] = ...,
-        ReplicaSettingsUpdate: Sequence[ReplicaSettingsUpdateTypeDef] = ...
+        ReplicaSettingsUpdate: Sequence[ReplicaSettingsUpdateTypeDef] = ...,
     ) -> UpdateGlobalTableSettingsOutputTypeDef:
         """
         Updates settings for a global table.
@@ -1097,28 +913,7 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TableName: str,
-        Key: Mapping[
-            str,
-            Union[
-                AttributeValueTypeDef,
-                Union[
-                    bytes,
-                    bytearray,
-                    str,
-                    int,
-                    Decimal,
-                    bool,
-                    Set[int],
-                    Set[Decimal],
-                    Set[str],
-                    Set[bytes],
-                    Set[bytearray],
-                    Sequence[Any],
-                    Mapping[str, Any],
-                    None,
-                ],
-            ],
-        ],
+        Key: Mapping[str, UniversalAttributeValueTypeDef],
         AttributeUpdates: Mapping[str, AttributeValueUpdateTypeDef] = ...,
         Expected: Mapping[str, ExpectedAttributeValueTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
@@ -1128,32 +923,13 @@ class DynamoDBClient(BaseClient):
         UpdateExpression: str = ...,
         ConditionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                AttributeValueTypeDef,
-                Union[
-                    bytes,
-                    bytearray,
-                    str,
-                    int,
-                    Decimal,
-                    bool,
-                    Set[int],
-                    Set[Decimal],
-                    Set[str],
-                    Set[bytes],
-                    Set[bytearray],
-                    Sequence[Any],
-                    Mapping[str, Any],
-                    None,
-                ],
-            ],
-        ] = ...
+        ExpressionAttributeValues: Mapping[str, UniversalAttributeValueTypeDef] = ...,
+        ReturnValuesOnConditionCheckFailure: ReturnValuesOnConditionCheckFailureType = ...,
     ) -> UpdateItemOutputTypeDef:
         """
         Edits an existing item's attributes, or adds a new item to the table if it does
-        not already exist.
+        not already
+        exist.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.update_item)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#update_item)
@@ -1171,11 +947,12 @@ class DynamoDBClient(BaseClient):
         SSESpecification: SSESpecificationTypeDef = ...,
         ReplicaUpdates: Sequence[ReplicationGroupUpdateTypeDef] = ...,
         TableClass: TableClassType = ...,
-        DeletionProtectionEnabled: bool = ...
+        DeletionProtectionEnabled: bool = ...,
     ) -> UpdateTableOutputTypeDef:
         """
         Modifies the provisioned throughput settings, global secondary indexes, or
-        DynamoDB Streams settings for a given table.
+        DynamoDB Streams settings for a given
+        table.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.update_table)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#update_table)
@@ -1187,7 +964,7 @@ class DynamoDBClient(BaseClient):
         TableName: str,
         GlobalSecondaryIndexUpdates: Sequence[GlobalSecondaryIndexAutoScalingUpdateTypeDef] = ...,
         ProvisionedWriteCapacityAutoScalingUpdate: AutoScalingSettingsUpdateTypeDef = ...,
-        ReplicaUpdates: Sequence[ReplicaAutoScalingUpdateTypeDef] = ...
+        ReplicaUpdates: Sequence[ReplicaAutoScalingUpdateTypeDef] = ...,
     ) -> UpdateTableReplicaAutoScalingOutputTypeDef:
         """
         Updates auto scaling settings on your global tables at once.
@@ -1201,7 +978,8 @@ class DynamoDBClient(BaseClient):
     ) -> UpdateTimeToLiveOutputTypeDef:
         """
         The `UpdateTimeToLive` method enables or disables Time to Live (TTL) for the
-        specified table.
+        specified
+        table.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.update_time_to_live)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#update_time_to_live)
