@@ -11,14 +11,14 @@ Usage::
     data: AttributeActionType = "ADD"
     ```
 """
+
 import sys
 
-if sys.version_info >= (3, 9):
+if sys.version_info >= (3, 12):
     from typing import Literal
 else:
     from typing_extensions import Literal
 
-
 __all__ = (
     "AttributeActionType",
     "BackupStatusType",
@@ -34,6 +34,8 @@ __all__ = (
     "DestinationStatusType",
     "ExportFormatType",
     "ExportStatusType",
+    "ExportTypeType",
+    "ExportViewTypeType",
     "GlobalTableStatusType",
     "ImportStatusType",
     "IndexStatusType",
@@ -71,7 +73,6 @@ __all__ = (
     "RegionName",
 )
 
-
 AttributeActionType = Literal["ADD", "DELETE", "PUT"]
 BackupStatusType = Literal["AVAILABLE", "CREATING", "DELETED"]
 BackupTypeFilterType = Literal["ALL", "AWS_BACKUP", "SYSTEM", "USER"]
@@ -112,6 +113,8 @@ ContributorInsightsStatusType = Literal["DISABLED", "DISABLING", "ENABLED", "ENA
 DestinationStatusType = Literal["ACTIVE", "DISABLED", "DISABLING", "ENABLE_FAILED", "ENABLING"]
 ExportFormatType = Literal["DYNAMODB_JSON", "ION"]
 ExportStatusType = Literal["COMPLETED", "FAILED", "IN_PROGRESS"]
+ExportTypeType = Literal["FULL_EXPORT", "INCREMENTAL_EXPORT"]
+ExportViewTypeType = Literal["NEW_AND_OLD_IMAGES", "NEW_IMAGE"]
 GlobalTableStatusType = Literal["ACTIVE", "CREATING", "DELETING", "UPDATING"]
 ImportStatusType = Literal["CANCELLED", "CANCELLING", "COMPLETED", "FAILED", "IN_PROGRESS"]
 IndexStatusType = Literal["ACTIVE", "CREATING", "DELETING", "UPDATING"]
@@ -173,6 +176,7 @@ ServiceName = Literal[
     "apigatewayv2",
     "appconfig",
     "appconfigdata",
+    "appfabric",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -187,10 +191,16 @@ ServiceName = Literal[
     "auditmanager",
     "autoscaling",
     "autoscaling-plans",
+    "b2bi",
     "backup",
     "backup-gateway",
     "backupstorage",
     "batch",
+    "bcm-data-exports",
+    "bedrock",
+    "bedrock-agent",
+    "bedrock-agent-runtime",
+    "bedrock-runtime",
     "billingconductor",
     "braket",
     "budgets",
@@ -202,11 +212,13 @@ ServiceName = Literal[
     "chime-sdk-messaging",
     "chime-sdk-voice",
     "cleanrooms",
+    "cleanroomsml",
     "cloud9",
     "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
+    "cloudfront-keyvaluestore",
     "cloudhsm",
     "cloudhsmv2",
     "cloudsearch",
@@ -220,6 +232,7 @@ ServiceName = Literal[
     "codecommit",
     "codedeploy",
     "codeguru-reviewer",
+    "codeguru-security",
     "codeguruprofiler",
     "codepipeline",
     "codestar",
@@ -238,12 +251,14 @@ ServiceName = Literal[
     "connectcases",
     "connectparticipant",
     "controltower",
+    "cost-optimization-hub",
     "cur",
     "customer-profiles",
     "databrew",
     "dataexchange",
     "datapipeline",
     "datasync",
+    "datazone",
     "dax",
     "detective",
     "devicefarm",
@@ -266,6 +281,7 @@ ServiceName = Literal[
     "ecs",
     "efs",
     "eks",
+    "eks-auth",
     "elastic-inference",
     "elasticache",
     "elasticbeanstalk",
@@ -275,6 +291,7 @@ ServiceName = Literal[
     "emr",
     "emr-containers",
     "emr-serverless",
+    "entityresolution",
     "es",
     "events",
     "evidently",
@@ -286,9 +303,9 @@ ServiceName = Literal[
     "forecast",
     "forecastquery",
     "frauddetector",
+    "freetier",
     "fsx",
     "gamelift",
-    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -305,6 +322,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector-scan",
     "inspector2",
     "internetmonitor",
     "iot",
@@ -325,6 +343,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivs-realtime",
     "ivschat",
     "kafka",
     "kafkaconnect",
@@ -342,6 +361,7 @@ ServiceName = Literal[
     "kms",
     "lakeformation",
     "lambda",
+    "launch-wizard",
     "lex-models",
     "lex-runtime",
     "lexv2-models",
@@ -357,10 +377,12 @@ ServiceName = Literal[
     "lookoutvision",
     "m2",
     "machinelearning",
-    "macie",
     "macie2",
     "managedblockchain",
+    "managedblockchain-query",
+    "marketplace-agreement",
     "marketplace-catalog",
+    "marketplace-deployment",
     "marketplace-entitlement",
     "marketplacecommerceanalytics",
     "mediaconnect",
@@ -368,9 +390,11 @@ ServiceName = Literal[
     "medialive",
     "mediapackage",
     "mediapackage-vod",
+    "mediapackagev2",
     "mediastore",
     "mediastore-data",
     "mediatailor",
+    "medical-imaging",
     "memorydb",
     "meteringmarketplace",
     "mgh",
@@ -384,8 +408,11 @@ ServiceName = Literal[
     "mturk",
     "mwaa",
     "neptune",
+    "neptune-graph",
+    "neptunedata",
     "network-firewall",
     "networkmanager",
+    "networkmonitor",
     "nimble",
     "oam",
     "omics",
@@ -394,8 +421,12 @@ ServiceName = Literal[
     "opsworks",
     "opsworkscm",
     "organizations",
+    "osis",
     "outposts",
     "panorama",
+    "payment-cryptography",
+    "payment-cryptography-data",
+    "pca-connector-ad",
     "personalize",
     "personalize-events",
     "personalize-runtime",
@@ -409,6 +440,8 @@ ServiceName = Literal[
     "pricing",
     "privatenetworks",
     "proton",
+    "qbusiness",
+    "qconnect",
     "qldb",
     "qldb-session",
     "quicksight",
@@ -420,6 +453,7 @@ ServiceName = Literal[
     "redshift-data",
     "redshift-serverless",
     "rekognition",
+    "repostspace",
     "resiliencehub",
     "resource-explorer-2",
     "resource-groups",
@@ -476,6 +510,7 @@ ServiceName = Literal[
     "stepfunctions",
     "storagegateway",
     "sts",
+    "supplychain",
     "support",
     "support-app",
     "swf",
@@ -487,7 +522,10 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "trustedadvisor",
+    "verifiedpermissions",
     "voice-id",
+    "vpc-lattice",
     "waf",
     "waf-regional",
     "wafv2",
@@ -498,6 +536,7 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-thin-client",
     "workspaces-web",
     "xray",
 ]
@@ -528,6 +567,7 @@ RegionName = Literal[
     "ap-southeast-3",
     "ap-southeast-4",
     "ca-central-1",
+    "ca-west-1",
     "eu-central-1",
     "eu-central-2",
     "eu-north-1",
@@ -536,6 +576,7 @@ RegionName = Literal[
     "eu-west-1",
     "eu-west-2",
     "eu-west-3",
+    "il-central-1",
     "me-central-1",
     "me-south-1",
     "sa-east-1",
