@@ -27,10 +27,8 @@ Usage::
     scan_paginator: ScanPaginator = client.get_paginator("scan")
     ```
 """
-from collections.abc import Mapping, Sequence
-from datetime import datetime
-from decimal import Decimal
-from typing import Any, Generic, Iterator, Set, TypeVar, Union
+
+from typing import Generic, Iterator, Mapping, Sequence, TypeVar
 
 from botocore.paginate import PageIterator, Paginator
 
@@ -41,13 +39,15 @@ from .literals import (
     SelectType,
 )
 from .type_defs import (
-    ConditionTableTypeDef,
-    ListBackupsOutputTableTypeDef,
-    ListTablesOutputTableTypeDef,
-    ListTagsOfResourceOutputTableTypeDef,
+    ConditionTypeDef,
+    ListBackupsOutputTypeDef,
+    ListTablesOutputTypeDef,
+    ListTagsOfResourceOutputTypeDef,
     PaginatorConfigTypeDef,
-    QueryOutputTableTypeDef,
-    ScanOutputTableTypeDef,
+    QueryOutputTypeDef,
+    ScanOutputTypeDef,
+    TimestampTypeDef,
+    UniversalAttributeValueTypeDef,
 )
 
 __all__ = (
@@ -58,7 +58,6 @@ __all__ = (
     "ScanPaginator",
 )
 
-
 _ItemTypeDef = TypeVar("_ItemTypeDef")
 
 
@@ -79,11 +78,11 @@ class ListBackupsPaginator(Paginator):
         self,
         *,
         TableName: str = ...,
-        TimeRangeLowerBound: Union[datetime, str] = ...,
-        TimeRangeUpperBound: Union[datetime, str] = ...,
+        TimeRangeLowerBound: TimestampTypeDef = ...,
+        TimeRangeUpperBound: TimestampTypeDef = ...,
         BackupType: BackupTypeFilterType = ...,
-        PaginationConfig: PaginatorConfigTypeDef = ...
-    ) -> _PageIterator[ListBackupsOutputTableTypeDef]:
+        PaginationConfig: PaginatorConfigTypeDef = ...,
+    ) -> _PageIterator[ListBackupsOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators/#listbackupspaginator)
@@ -98,7 +97,7 @@ class ListTablesPaginator(Paginator):
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = ...
-    ) -> _PageIterator[ListTablesOutputTableTypeDef]:
+    ) -> _PageIterator[ListTablesOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators/#listtablespaginator)
@@ -113,7 +112,7 @@ class ListTagsOfResourcePaginator(Paginator):
 
     def paginate(
         self, *, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
-    ) -> _PageIterator[ListTagsOfResourceOutputTableTypeDef]:
+    ) -> _PageIterator[ListTagsOfResourceOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators/#listtagsofresourcepaginator)
@@ -134,8 +133,8 @@ class QueryPaginator(Paginator):
         Select: SelectType = ...,
         AttributesToGet: Sequence[str] = ...,
         ConsistentRead: bool = ...,
-        KeyConditions: Mapping[str, ConditionTableTypeDef] = ...,
-        QueryFilter: Mapping[str, ConditionTableTypeDef] = ...,
+        KeyConditions: Mapping[str, ConditionTypeDef] = ...,
+        QueryFilter: Mapping[str, ConditionTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ScanIndexForward: bool = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
@@ -143,27 +142,9 @@ class QueryPaginator(Paginator):
         FilterExpression: str = ...,
         KeyConditionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...,
-        PaginationConfig: PaginatorConfigTypeDef = ...
-    ) -> _PageIterator[QueryOutputTableTypeDef]:
+        ExpressionAttributeValues: Mapping[str, UniversalAttributeValueTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...,
+    ) -> _PageIterator[QueryOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators/#querypaginator)
@@ -183,7 +164,7 @@ class ScanPaginator(Paginator):
         IndexName: str = ...,
         AttributesToGet: Sequence[str] = ...,
         Select: SelectType = ...,
-        ScanFilter: Mapping[str, ConditionTableTypeDef] = ...,
+        ScanFilter: Mapping[str, ConditionTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         TotalSegments: int = ...,
@@ -191,28 +172,10 @@ class ScanPaginator(Paginator):
         ProjectionExpression: str = ...,
         FilterExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...,
+        ExpressionAttributeValues: Mapping[str, UniversalAttributeValueTypeDef] = ...,
         ConsistentRead: bool = ...,
-        PaginationConfig: PaginatorConfigTypeDef = ...
-    ) -> _PageIterator[ScanOutputTableTypeDef]:
+        PaginationConfig: PaginatorConfigTypeDef = ...,
+    ) -> _PageIterator[ScanOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators/#scanpaginator)
