@@ -17,11 +17,10 @@ Usage::
     my_table: dynamodb_resources.Table = resource.Table(...)
 ```
 """
-from datetime import datetime
-from decimal import Decimal
-from typing import Any, Iterator, List, Mapping, Sequence, Set, Union
 
-from boto3.dynamodb.conditions import ConditionBase
+from datetime import datetime
+from typing import Iterator, List, Mapping, Sequence
+
 from boto3.dynamodb.table import BatchWriter
 from boto3.resources.base import ResourceMeta, ServiceResource
 from boto3.resources.collection import ResourceCollection
@@ -32,49 +31,47 @@ from .literals import (
     ConditionalOperatorType,
     ReturnConsumedCapacityType,
     ReturnItemCollectionMetricsType,
+    ReturnValuesOnConditionCheckFailureType,
     ReturnValueType,
     SelectType,
     TableClassType,
     TableStatusType,
 )
 from .type_defs import (
-    ArchivalSummaryResponseMetadataTypeDef,
-    AttributeDefinitionServiceResourceTypeDef,
-    AttributeDefinitionTableTypeDef,
+    ArchivalSummaryResponseTypeDef,
+    AttributeDefinitionTypeDef,
     AttributeValueUpdateTableTypeDef,
     BatchGetItemOutputServiceResourceTypeDef,
     BatchWriteItemOutputServiceResourceTypeDef,
-    BillingModeSummaryResponseMetadataTypeDef,
+    BillingModeSummaryResponseTypeDef,
+    ConditionBaseImportTypeDef,
     ConditionTableTypeDef,
     DeleteItemOutputTableTypeDef,
     DeleteTableOutputTableTypeDef,
     ExpectedAttributeValueTableTypeDef,
     GetItemOutputTableTypeDef,
     GlobalSecondaryIndexDescriptionTableTypeDef,
-    GlobalSecondaryIndexServiceResourceTypeDef,
+    GlobalSecondaryIndexTypeDef,
     GlobalSecondaryIndexUpdateTableTypeDef,
     KeysAndAttributesServiceResourceTypeDef,
-    KeySchemaElementServiceResourceTypeDef,
-    KeySchemaElementTableTypeDef,
+    KeySchemaElementTypeDef,
     LocalSecondaryIndexDescriptionTableTypeDef,
-    LocalSecondaryIndexServiceResourceTypeDef,
-    ProvisionedThroughputDescriptionResponseMetadataTypeDef,
-    ProvisionedThroughputServiceResourceTypeDef,
-    ProvisionedThroughputTableTypeDef,
+    LocalSecondaryIndexTypeDef,
+    ProvisionedThroughputDescriptionResponseTypeDef,
+    ProvisionedThroughputTypeDef,
     PutItemOutputTableTypeDef,
     QueryOutputTableTypeDef,
-    ReplicaDescriptionTableTypeDef,
-    ReplicationGroupUpdateTableTypeDef,
-    RestoreSummaryResponseMetadataTypeDef,
+    ReplicaDescriptionTypeDef,
+    ReplicationGroupUpdateTypeDef,
+    RestoreSummaryResponseTypeDef,
     ScanOutputTableTypeDef,
-    SSEDescriptionResponseMetadataTypeDef,
-    SSESpecificationServiceResourceTypeDef,
-    SSESpecificationTableTypeDef,
-    StreamSpecificationResponseMetadataTypeDef,
-    StreamSpecificationServiceResourceTypeDef,
-    StreamSpecificationTableTypeDef,
-    TableClassSummaryResponseMetadataTypeDef,
-    TagServiceResourceTypeDef,
+    SSEDescriptionResponseTypeDef,
+    SSESpecificationTypeDef,
+    StreamSpecificationResponseTypeDef,
+    StreamSpecificationTypeDef,
+    TableAttributeValueTypeDef,
+    TableClassSummaryResponseTypeDef,
+    TagTypeDef,
     UpdateItemOutputTableTypeDef,
     WriteRequestServiceResourceTypeDef,
 )
@@ -145,30 +142,31 @@ class Table(ServiceResource):
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource/#table)
     """
 
-    attribute_definitions: List[AttributeDefinitionTableTypeDef]
+    attribute_definitions: List[AttributeDefinitionTypeDef]
     table_name: str
-    key_schema: List[KeySchemaElementTableTypeDef]
+    key_schema: List[KeySchemaElementTypeDef]
     table_status: TableStatusType
     creation_date_time: datetime
-    provisioned_throughput: ProvisionedThroughputDescriptionResponseMetadataTypeDef
+    provisioned_throughput: ProvisionedThroughputDescriptionResponseTypeDef
     table_size_bytes: int
     item_count: int
     table_arn: str
     table_id: str
-    billing_mode_summary: BillingModeSummaryResponseMetadataTypeDef
+    billing_mode_summary: BillingModeSummaryResponseTypeDef
     local_secondary_indexes: List[LocalSecondaryIndexDescriptionTableTypeDef]
     global_secondary_indexes: List[GlobalSecondaryIndexDescriptionTableTypeDef]
-    stream_specification: StreamSpecificationResponseMetadataTypeDef
+    stream_specification: StreamSpecificationResponseTypeDef
     latest_stream_label: str
     latest_stream_arn: str
     global_table_version: str
-    replicas: List[ReplicaDescriptionTableTypeDef]
-    restore_summary: RestoreSummaryResponseMetadataTypeDef
-    sse_description: SSEDescriptionResponseMetadataTypeDef
-    archival_summary: ArchivalSummaryResponseMetadataTypeDef
-    table_class_summary: TableClassSummaryResponseMetadataTypeDef
+    replicas: List[ReplicaDescriptionTypeDef]
+    restore_summary: RestoreSummaryResponseTypeDef
+    sse_description: SSEDescriptionResponseTypeDef
+    archival_summary: ArchivalSummaryResponseTypeDef
+    table_class_summary: TableClassSummaryResponseTypeDef
     deletion_protection_enabled: bool
     name: str
+    meta: "DynamoDBResourceMeta"
 
     def batch_writer(self, overwrite_by_pkeys: List[str] = ...) -> BatchWriter:
         """
@@ -189,51 +187,16 @@ class Table(ServiceResource):
     def delete_item(
         self,
         *,
-        Key: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ],
+        Key: Mapping[str, TableAttributeValueTypeDef],
         Expected: Mapping[str, ExpectedAttributeValueTableTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ReturnValues: ReturnValueType = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
-        ConditionExpression: Union[str, ConditionBase] = ...,
+        ConditionExpression: ConditionBaseImportTypeDef = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...
+        ExpressionAttributeValues: Mapping[str, TableAttributeValueTypeDef] = ...,
+        ReturnValuesOnConditionCheckFailure: ReturnValuesOnConditionCheckFailureType = ...,
     ) -> DeleteItemOutputTableTypeDef:
         """
         Deletes a single item in a table by primary key.
@@ -253,34 +216,17 @@ class Table(ServiceResource):
     def get_item(
         self,
         *,
-        Key: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ],
+        Key: Mapping[str, TableAttributeValueTypeDef],
         AttributesToGet: Sequence[str] = ...,
         ConsistentRead: bool = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ProjectionExpression: str = ...,
-        ExpressionAttributeNames: Mapping[str, str] = ...
+        ExpressionAttributeNames: Mapping[str, str] = ...,
     ) -> GetItemOutputTableTypeDef:
         """
         The `GetItem` operation returns a set of attributes for the item with the given
-        primary key.
+        primary
+        key.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Table.get_item)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource/#tableget_item-method)
@@ -289,7 +235,8 @@ class Table(ServiceResource):
     def load(self) -> None:
         """
         Calls :py:meth:`DynamoDB.Client.describe_table` to update the attributes of the
-        Table resource.
+        Table
+        resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Table.load)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource/#tableload-method)
@@ -298,51 +245,16 @@ class Table(ServiceResource):
     def put_item(
         self,
         *,
-        Item: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ],
+        Item: Mapping[str, TableAttributeValueTypeDef],
         Expected: Mapping[str, ExpectedAttributeValueTableTypeDef] = ...,
         ReturnValues: ReturnValueType = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
-        ConditionExpression: Union[str, ConditionBase] = ...,
+        ConditionExpression: ConditionBaseImportTypeDef = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...
+        ExpressionAttributeValues: Mapping[str, TableAttributeValueTypeDef] = ...,
+        ReturnValuesOnConditionCheckFailure: ReturnValuesOnConditionCheckFailureType = ...,
     ) -> PutItemOutputTableTypeDef:
         """
         Creates a new item, or replaces an old item with a new item.
@@ -363,53 +275,18 @@ class Table(ServiceResource):
         QueryFilter: Mapping[str, ConditionTableTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ScanIndexForward: bool = ...,
-        ExclusiveStartKey: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...,
+        ExclusiveStartKey: Mapping[str, TableAttributeValueTypeDef] = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ProjectionExpression: str = ...,
-        FilterExpression: Union[str, ConditionBase] = ...,
-        KeyConditionExpression: Union[str, ConditionBase] = ...,
+        FilterExpression: ConditionBaseImportTypeDef = ...,
+        KeyConditionExpression: ConditionBaseImportTypeDef = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...
+        ExpressionAttributeValues: Mapping[str, TableAttributeValueTypeDef] = ...,
     ) -> QueryOutputTableTypeDef:
         """
         You must provide the name of the partition key attribute and a single value for
-        that attribute.
+        that
+        attribute.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Table.query)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource/#tablequery-method)
@@ -418,7 +295,8 @@ class Table(ServiceResource):
     def reload(self) -> None:
         """
         Calls :py:meth:`DynamoDB.Client.describe_table` to update the attributes of the
-        Table resource.
+        Table
+        resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Table.reload)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource/#tablereload-method)
@@ -433,55 +311,20 @@ class Table(ServiceResource):
         Select: SelectType = ...,
         ScanFilter: Mapping[str, ConditionTableTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
-        ExclusiveStartKey: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...,
+        ExclusiveStartKey: Mapping[str, TableAttributeValueTypeDef] = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         TotalSegments: int = ...,
         Segment: int = ...,
         ProjectionExpression: str = ...,
-        FilterExpression: Union[str, ConditionBase] = ...,
+        FilterExpression: ConditionBaseImportTypeDef = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...,
-        ConsistentRead: bool = ...
+        ExpressionAttributeValues: Mapping[str, TableAttributeValueTypeDef] = ...,
+        ConsistentRead: bool = ...,
     ) -> ScanOutputTableTypeDef:
         """
         The `Scan` operation returns one or more items and item attributes by accessing
-        every item in a table or a secondary index.
+        every item in a table or a secondary
+        index.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Table.scan)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource/#tablescan-method)
@@ -490,19 +333,20 @@ class Table(ServiceResource):
     def update(
         self,
         *,
-        AttributeDefinitions: Sequence[AttributeDefinitionTableTypeDef] = ...,
+        AttributeDefinitions: Sequence[AttributeDefinitionTypeDef] = ...,
         BillingMode: BillingModeType = ...,
-        ProvisionedThroughput: ProvisionedThroughputTableTypeDef = ...,
+        ProvisionedThroughput: ProvisionedThroughputTypeDef = ...,
         GlobalSecondaryIndexUpdates: Sequence[GlobalSecondaryIndexUpdateTableTypeDef] = ...,
-        StreamSpecification: StreamSpecificationTableTypeDef = ...,
-        SSESpecification: SSESpecificationTableTypeDef = ...,
-        ReplicaUpdates: Sequence[ReplicationGroupUpdateTableTypeDef] = ...,
+        StreamSpecification: StreamSpecificationTypeDef = ...,
+        SSESpecification: SSESpecificationTypeDef = ...,
+        ReplicaUpdates: Sequence[ReplicationGroupUpdateTypeDef] = ...,
         TableClass: TableClassType = ...,
-        DeletionProtectionEnabled: bool = ...
+        DeletionProtectionEnabled: bool = ...,
     ) -> "_Table":
         """
         Modifies the provisioned throughput settings, global secondary indexes, or
-        DynamoDB Streams settings for a given table.
+        DynamoDB Streams settings for a given
+        table.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Table.update)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource/#tableupdate-method)
@@ -511,25 +355,7 @@ class Table(ServiceResource):
     def update_item(
         self,
         *,
-        Key: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ],
+        Key: Mapping[str, TableAttributeValueTypeDef],
         AttributeUpdates: Mapping[str, AttributeValueUpdateTableTypeDef] = ...,
         Expected: Mapping[str, ExpectedAttributeValueTableTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
@@ -537,31 +363,15 @@ class Table(ServiceResource):
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
         UpdateExpression: str = ...,
-        ConditionExpression: Union[str, ConditionBase] = ...,
+        ConditionExpression: ConditionBaseImportTypeDef = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
-        ExpressionAttributeValues: Mapping[
-            str,
-            Union[
-                bytes,
-                bytearray,
-                str,
-                int,
-                Decimal,
-                bool,
-                Set[int],
-                Set[Decimal],
-                Set[str],
-                Set[bytes],
-                Set[bytearray],
-                Sequence[Any],
-                Mapping[str, Any],
-                None,
-            ],
-        ] = ...
+        ExpressionAttributeValues: Mapping[str, TableAttributeValueTypeDef] = ...,
+        ReturnValuesOnConditionCheckFailure: ReturnValuesOnConditionCheckFailureType = ...,
     ) -> UpdateItemOutputTableTypeDef:
         """
         Edits an existing item's attributes, or adds a new item to the table if it does
-        not already exist.
+        not already
+        exist.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Table.update_item)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource/#tableupdate_item-method)
@@ -600,7 +410,7 @@ class DynamoDBServiceResource(ServiceResource):
     meta: "DynamoDBResourceMeta"
     tables: ServiceResourceTablesCollection
 
-    def Table(self, name: str) -> _Table:
+    def Table(self, name: str) -> "_Table":
         """
         Creates a Table resource.
 
@@ -612,11 +422,12 @@ class DynamoDBServiceResource(ServiceResource):
         self,
         *,
         RequestItems: Mapping[str, KeysAndAttributesServiceResourceTypeDef],
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
     ) -> BatchGetItemOutputServiceResourceTypeDef:
         """
         The `BatchGetItem` operation returns the attributes of one or more items from
-        one or more tables.
+        one or more
+        tables.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource/#dynamodbserviceresourcebatch_get_item-method)
@@ -627,7 +438,7 @@ class DynamoDBServiceResource(ServiceResource):
         *,
         RequestItems: Mapping[str, Sequence[WriteRequestServiceResourceTypeDef]],
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
-        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
     ) -> BatchWriteItemOutputServiceResourceTypeDef:
         """
         The `BatchWriteItem` operation puts or deletes multiple items in one or more
@@ -640,19 +451,19 @@ class DynamoDBServiceResource(ServiceResource):
     def create_table(
         self,
         *,
-        AttributeDefinitions: Sequence[AttributeDefinitionServiceResourceTypeDef],
+        AttributeDefinitions: Sequence[AttributeDefinitionTypeDef],
         TableName: str,
-        KeySchema: Sequence[KeySchemaElementServiceResourceTypeDef],
-        LocalSecondaryIndexes: Sequence[LocalSecondaryIndexServiceResourceTypeDef] = ...,
-        GlobalSecondaryIndexes: Sequence[GlobalSecondaryIndexServiceResourceTypeDef] = ...,
+        KeySchema: Sequence[KeySchemaElementTypeDef],
+        LocalSecondaryIndexes: Sequence[LocalSecondaryIndexTypeDef] = ...,
+        GlobalSecondaryIndexes: Sequence[GlobalSecondaryIndexTypeDef] = ...,
         BillingMode: BillingModeType = ...,
-        ProvisionedThroughput: ProvisionedThroughputServiceResourceTypeDef = ...,
-        StreamSpecification: StreamSpecificationServiceResourceTypeDef = ...,
-        SSESpecification: SSESpecificationServiceResourceTypeDef = ...,
-        Tags: Sequence[TagServiceResourceTypeDef] = ...,
+        ProvisionedThroughput: ProvisionedThroughputTypeDef = ...,
+        StreamSpecification: StreamSpecificationTypeDef = ...,
+        SSESpecification: SSESpecificationTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         TableClass: TableClassType = ...,
-        DeletionProtectionEnabled: bool = ...
-    ) -> _Table:
+        DeletionProtectionEnabled: bool = ...,
+    ) -> "_Table":
         """
         The `CreateTable` operation adds a new table to your account.
 
